@@ -3,8 +3,8 @@
 import logging
 from typing import Any, Dict, List, Optional, Tuple, cast
 
-from gpt_index.data_structs.data_structs import IndexGraph, Node
-from gpt_index.embeddings.base import BaseEmbedding
+from gpt_index.data_structs.data_structs_v2 import IndexGraph
+from gpt_index.data_structs.node_v2 import Node
 from gpt_index.indices.query.schema import QueryBundle
 from gpt_index.indices.query.tree.leaf_query import GPTTreeIndexLeafQuery
 from gpt_index.indices.utils import get_sorted_node_list
@@ -49,7 +49,6 @@ class GPTTreeIndexEmbeddingQuery(GPTTreeIndexLeafQuery):
         query_template: Optional[TreeSelectPrompt] = None,
         query_template_multiple: Optional[TreeSelectMultiplePrompt] = None,
         child_branch_factor: int = 1,
-        embed_model: Optional[BaseEmbedding] = None,
         **kwargs: Any,
     ) -> None:
         """Initialize params."""
@@ -58,17 +57,21 @@ class GPTTreeIndexEmbeddingQuery(GPTTreeIndexLeafQuery):
             query_template=query_template,
             query_template_multiple=query_template_multiple,
             child_branch_factor=child_branch_factor,
-            embed_model=embed_model,
             **kwargs,
         )
         self.child_branch_factor = child_branch_factor
 
     def _query_level(
         self,
-        cur_nodes: Dict[int, Node],
+        cur_node_ids: Dict[int, str],
         query_bundle: QueryBundle,
         level: int = 0,
     ) -> str:
+        """Answer a query recursively."""
+        cur_nodes = {
+            index: self._docstore.get_node(node_id)
+            for index, node_id in cur_node_ids.items()
+        }
         cur_node_list = get_sorted_node_list(cur_nodes)
 
         # Get the node with the highest similarity to the query
@@ -100,15 +103,19 @@ class GPTTreeIndexEmbeddingQuery(GPTTreeIndexLeafQuery):
 
         """
         if query_bundle.embedding is None:
-            query_bundle.embedding = self._embed_model.get_agg_embedding_from_queries(
-                query_bundle.embedding_strs
+            query_bundle.embedding = (
+                self._service_context.embed_model.get_agg_embedding_from_queries(
+                    query_bundle.embedding_strs
+                )
             )
         similarities = []
         for node in nodes:
             if node.embedding is None:
-                node.embedding = self._embed_model.get_text_embedding(node.get_text())
+                node.embedding = self._service_context.embed_model.get_text_embedding(
+                    node.get_text()
+                )
 
-            similarity = self._embed_model.similarity(
+            similarity = self._service_context.embed_model.similarity(
                 query_bundle.embedding, node.embedding
             )
             similarities.append(similarity)
@@ -132,3 +139,12 @@ class GPTTreeIndexEmbeddingQuery(GPTTreeIndexLeafQuery):
                 break
 
         return selected_nodes, selected_indices
+
+    def _select_nodes(
+        self,
+        cur_node_list: List[Node],
+        query_bundle: QueryBundle,
+        level: int = 0,
+    ) -> List[Node]:
+        selected_nodes, _ = self._get_most_similar_nodes(cur_node_list, query_bundle)
+        return selected_nodes
