@@ -3,7 +3,8 @@
 import logging
 from typing import Any, List, Optional, cast
 
-from gpt_index.data_structs.data_structs import IndexGraph, Node
+from gpt_index.data_structs.data_structs_v2 import IndexGraph
+from gpt_index.data_structs.node_v2 import Node
 from gpt_index.indices.query.base import BaseGPTIndexQuery
 from gpt_index.indices.query.embedding_utils import SimilarityTracker
 from gpt_index.indices.query.schema import QueryBundle
@@ -50,7 +51,7 @@ class GPTTreeIndexSummarizeQuery(BaseGPTIndexQuery[IndexGraph]):
             **kwargs,
         )
 
-    def _get_nodes_for_response(
+    def _retrieve(
         self,
         query_bundle: QueryBundle,
         similarity_tracker: Optional[SimilarityTracker] = None,
@@ -58,5 +59,6 @@ class GPTTreeIndexSummarizeQuery(BaseGPTIndexQuery[IndexGraph]):
         """Get nodes for response."""
         logger.info(f"> Starting query: {query_bundle.query_str}")
         index_struct = cast(IndexGraph, self._index_struct)
-        sorted_node_list = get_sorted_node_list(index_struct.all_nodes)
+        all_nodes = self._docstore.get_node_dict(index_struct.all_nodes)
+        sorted_node_list = get_sorted_node_list(all_nodes)
         return sorted_node_list
