@@ -5,7 +5,7 @@ from typing import Any, Dict, Optional
 
 from requests.adapters import Retry
 
-from gpt_index.data_structs.data_structs import IndexDict
+from gpt_index.data_structs.data_structs_v2 import IndexDict
 from gpt_index.indices.query.vector_store.base import GPTVectorStoreIndexQuery
 from gpt_index.vector_stores import (
     ChatGPTRetrievalPluginClient,
