@@ -1,8 +1,9 @@
 """Structured store indices."""
 
+from gpt_index.indices.struct_store.pandas import GPTPandasIndex
 from gpt_index.indices.struct_store.sql import (
     GPTSQLStructStoreIndex,
     SQLContextContainerBuilder,
 )
 
-__all__ = ["GPTSQLStructStoreIndex", "SQLContextContainerBuilder"]
+__all__ = ["GPTSQLStructStoreIndex", "SQLContextContainerBuilder", "GPTPandasIndex"]
