@@ -2,6 +2,7 @@
 
 from gpt_index.indices.vector_store.base import GPTVectorStoreIndex
 from gpt_index.indices.vector_store.vector_indices import (
+    ChatGPTRetrievalPluginIndex,
     GPTChromaIndex,
     GPTFaissIndex,
     GPTOpensearchIndex,
@@ -20,4 +21,5 @@ __all__ = [
     "GPTQdrantIndex",
     "GPTChromaIndex",
     "GPTOpensearchIndex",
+    "ChatGPTRetrievalPluginIndex",
 ]
