@@ -3,49 +3,10 @@
 from dataclasses import dataclass, field
 from typing import Any, Dict, Generator, List, Optional, Union
 
-from dataclasses_json import DataClassJsonMixin
-
-from gpt_index.data_structs.node_v2 import Node
+from gpt_index.data_structs.node_v2 import NodeWithScore
 from gpt_index.utils import truncate_text
 
 
-@dataclass
-class SourceNode(DataClassJsonMixin):
-    """Source node.
-
-    User-facing class containing the source text and the corresponding document id.
-
-    """
-
-    source_text: str
-    doc_id: Optional[str]
-    extra_info: Optional[Dict[str, Any]] = None
-    node_info: Optional[Dict[str, Any]] = None
-
-    # distance score between node and query, if applicable
-    similarity: Optional[float] = None
-
-    # TODO: store reference instead of actual image
-    # base64 encoded image str
-    image: Optional[str] = None
-
-    @classmethod
-    def from_node(cls, node: Node, similarity: Optional[float] = None) -> "SourceNode":
-        """Create a SourceNode from a Node."""
-        return cls(
-            source_text=node.get_text(),
-            doc_id=node.ref_doc_id,
-            extra_info=node.extra_info,
-            node_info=node.node_info,
-            similarity=similarity,
-        )
-
-    @classmethod
-    def from_nodes(cls, nodes: List[Node]) -> List["SourceNode"]:
-        """Create a list of SourceNodes from a list of Nodes."""
-        return [cls.from_node(node) for node in nodes]
-
-
 @dataclass
 class Response:
     """Response object.
@@ -58,7 +19,7 @@ class Response:
     """
 
     response: Optional[str]
-    source_nodes: List[SourceNode] = field(default_factory=list)
+    source_nodes: List[NodeWithScore] = field(default_factory=list)
     extra_info: Optional[Dict[str, Any]] = None
 
     def __str__(self) -> str:
@@ -88,7 +49,7 @@ class StreamingResponse:
     """
 
     response_gen: Optional[Generator]
-    source_nodes: List[SourceNode] = field(default_factory=list)
+    source_nodes: List[NodeWithScore] = field(default_factory=list)
     extra_info: Optional[Dict[str, Any]] = None
     response_txt: Optional[str] = None
 
