@@ -6,7 +6,7 @@ from unittest.mock import patch
 
 import pytest
 
-from gpt_index.data_structs.data_structs import Node
+from gpt_index.data_structs.node_v2 import Node
 from gpt_index.embeddings.base import mean_agg
 from gpt_index.embeddings.openai import OpenAIEmbedding
 from gpt_index.indices.query.tree.embedding_query import GPTTreeIndexEmbeddingQuery
@@ -113,7 +113,7 @@ def test_embedding_query(
 ) -> None:
     """Test embedding query."""
     index_kwargs, query_kwargs = struct_kwargs
-    tree = GPTTreeIndex(documents, **index_kwargs)
+    tree = GPTTreeIndex.from_documents(documents, **index_kwargs)
 
     # test embedding query
     query_str = "What is?"
@@ -164,13 +164,13 @@ def test_query_and_count_tokens(
     llmchain_mock_resp_token_count = 4
     # build the tree
     # TMP
-    tree = GPTTreeIndex(documents, **index_kwargs)
-    assert tree._llm_predictor.total_tokens_used == (
+    tree = GPTTreeIndex.from_documents(documents, **index_kwargs)
+    assert tree.service_context.llm_predictor.total_tokens_used == (
         first_block_count + llmchain_mock_resp_token_count
     ) + (second_block_count + llmchain_mock_resp_token_count)
 
     # test embedding query
-    start_token_ct = tree._llm_predictor.total_tokens_used
+    start_token_ct = tree._service_context.llm_predictor.total_tokens_used
     query_str = "What is?"
     # context is "hello world." which is 2 tokens
     context_tokens = 2
@@ -181,6 +181,6 @@ def test_query_and_count_tokens(
 
     tree.query(query_str, mode="embedding", **query_kwargs)
     assert (
-        tree._llm_predictor.total_tokens_used - start_token_ct
+        tree.service_context.llm_predictor.total_tokens_used - start_token_ct
         == input_tokens + llmchain_mock_resp_token_count
     )
