@@ -41,8 +41,8 @@ def test_decompose_query_transform(
 
     # initialize list index
     # documents aren't used for this test
-    index = GPTListIndex(documents)
-    index.set_text("Foo bar")
+    index = GPTListIndex.from_documents(documents)
+    index.index_struct.summary = "Foo bar"
     query_str = "What is?"
     new_query_bundle = query_transform.run(
         query_str, {"index_struct": index.index_struct}
